import 'package:flutter/material.dart';
import 'package:progamification/src/constants/color_contants.dart';
import 'package:progamification/src/controllers/leader_board.dart';
import 'package:get/get.dart';
import 'package:progamification/src/models/leader_board.dart';
import 'package:progamification/src/services/sas_token.service.dart';
import 'package:progamification/src/services/storage.service.dart';
import 'package:google_fonts/google_fonts.dart';

import 'linear_progress_indicator.dart';

class Progress extends StatefulWidget {
  const Progress({super.key});

  @override
  State<Progress> createState() => _ProgressState();
}

class _ProgressState extends State<Progress> {
  LeaderBoardController leaderBoardController =
      Get.find<LeaderBoardController>();
  LeaderBoardModel? currentUser = LeaderBoardModel();
  final GamificationStorageService storageService =
      Get.find<GamificationStorageService>();

  SasTokenService sasTokenService = Get.find<SasTokenService>();
  String sasToken = "";

  @override
  initState() {
    setCurrentUserLeaderBoardData();
    super.initState();
    sasTokenService.getSasToken().then((value) {
      setState(() {
        sasToken = value.toString();
      });
    });
  }

  TextStyle textStyle({Color fontColor = Colors.black}) => TextStyle(
      color: fontColor,
      fontSize: 18.0,
      fontFamily: GoogleFonts.plusJakartaSans().fontFamily,
      fontWeight: FontWeight.w600);

  @override
  Widget build(BuildContext context) {
    String points = leaderBoardController.userRewards['points'] ?? '';
    return Container(
        margin: const EdgeInsets.only(top: 15.0),
        decoration: BoxDecoration(
            color: ColorConstants.greyBgColor,
            border: const Border(
              bottom: BorderSide(
                color: Color.fromARGB(255, 228, 228, 228),
                width: 1.0,
              ),
            )),
        padding: const EdgeInsets.only(
            left: 20.0, right: 20.0, top: 25.0, bottom: 35.0),
        child: Column(
          children: [
            Padding(
                padding: const EdgeInsets.only(top: 10.0, bottom: 30.0),
                child: Row(
                  mainAxisAlignment: MainAxisAlignment.spaceBetween,
                  children: [
                    Text(
                      "Progress",
                      style: textStyle(),
                    ),
                    Row(children: [
                      Image.asset(
                        "assets/icons/bolt.png",
                        package: "progamification",
                      ),
                      const SizedBox(
                        width: 10.0,
                      ),
                      Text.rich(TextSpan(
                          style: textStyle(),
                          text: currentUser!.score.toString(),
                          children: <InlineSpan>[
                            TextSpan(
                              text: points != '' ? ' / $points' : '',
                              style: textStyle(fontColor: Colors.grey),
                            )
                          ])),
                    ]),
                  ],
                )),
            LinearGradientProgressIndicator(
              value: double.parse(
                  (leaderBoardController.userRewards["progress"]) as String),
              backgroundColor: ColorConstants.progressBgColor,
              gradientColors: [
                ColorConstants.progressGrad1Color,
                ColorConstants.progressGrad2Color,
              ],
              borderColor: ColorConstants.progressBorderColor,
            )
          ],
        ));
  }

  Future<void> setCurrentUserLeaderBoardData() async {
    String userId = await storageService.getString('userId');
    LeaderBoardModel leaderboard =
        leaderBoardController.getLeaderBoardData(userId);
    setState(() {
      currentUser = leaderboard;
    });
  }
}
